@@ -12,15 +12,30 @@
 #include <config-kdebugsettings.h>
 
 #include <KAboutData>
+#if HAVE_KDBUSADDONS
 #include <KDBusService>
+#endif
 #include <KLocalizedString>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
 #include <iostream>
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 int main(int argc, char **argv)
 {
+#if HAVE_KICONTHEME && (KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+    KIconTheme::initTheme();
+#endif
     QApplication app(argc, argv);
 
     KAboutData aboutData(QStringLiteral("kdebugsettings"),
@@ -29,7 +44,14 @@ int main(int argc, char **argv)
                          i18n("Configure debug settings"),
                          KAboutLicense::GPL_V2,
                          i18n("(c) 2015-%1 kdebugsettings authors", QStringLiteral("2024")));
-    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+#endif
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("debug-run")));
     KAboutData::setApplicationData(aboutData);
 
@@ -87,7 +109,9 @@ int main(int argc, char **argv)
         }
         return 1;
     } else {
+#if HAVE_KDBUSADDONS
         KDBusService service(KDBusService::Unique);
+#endif
         auto dialog = new KDebugSettingsDialog;
         const int ret = dialog->exec();
         delete dialog;
